@@ -198,6 +198,10 @@ class StickerDownloader:
 			img = Image.open(inputFile)
 			img.save(inputFile.replace("input", "webp"))
 			img.save(inputFile.replace("webp", "png").replace("input", "png"))
+			try:
+				img.save(inputFile.replace("webp", "gif").replace("input", "gif"), transparency=0)
+			except ValueError:
+				print("Failed to save {} as gif".format(inputFile))
 		else:
 			copy(inputFile, inputFile.replace("input", "tgs"))
 			images, duration = animate.convertTGS2PIL(inputFile)
